
# Vehicle Choice Examples

**Example Data**

This data is generously provided by Kenneth Train, who has used and published it
in conjunction with his own teaching on mixed logit model estimation. The data
represent consumers' choices among vehicles in stated preference
experiments, taken from a study that he did for Toyota and GM to assist
them in their analysis of the potential marketability of electric and hybrid
vehicles, back before hybrids were introduced.

In each choice experiment, the respondent was presented with three vehicles,
with the price and other attributes of each vehicle described. The respondent
was asked to state which of the three vehicles they would buy if the these
vehicles were the only ones available in the market. There are 100 respondents
in this sample dataset. (The actual dataset used for industrial design purposes
was much larger, but this size is sufficient for educational purposes.) Each
respondent was presented with 15 choice experiments, and most respondents
answered all 15. The attributes of the vehicles were varied over experiments,
both for a given respondent and over respondents. The attributes are:

- price,
- operating cost in dollars per month,
- engine type (gas, electric, or hybrid),
- range if electric (in hundreds of miles between recharging), and
- the performance level of the vehicle (high, medium, or low).

The performance level was described in terms of top speed and acceleration, and
these descriptions did not vary for each level; for example, "High" performance
was described as having a top speed of 100 mph and 12 seconds to reach 60 mph,
and this description was the same for all "high" performance vehicles.

```{toctree}
:glob:

3*
```
